pub struct ObjectClient<'ctx> { /* private fields */ }Expand description
Struct exposing the client to invoke [#service_ident] from another service.
Implementations
Sourceimpl<'ctx> ObjectClient<'ctx>
Struct exposing the client to invoke Object from another service.
impl<'ctx> ObjectClient<'ctx>
Struct exposing the client to invoke Object from another service.
pub fn create(&self, req: Json<JobSpec>) -> Request<'ctx, Json<JobSpec>, ()>
pub fn replace(&self, req: Json<JobSpec>) -> Request<'ctx, Json<JobSpec>, ()>
pub fn cancel(&self) -> Request<'ctx, (), ()>
pub fn run(&self) -> Request<'ctx, (), ()>
pub fn get(&self) -> Request<'ctx, (), Json<JobSpec>>
pub fn get_next_run(&self) -> Request<'ctx, (), Json<NextRun>>